[gold] Rename "skiacorrectness" to "frontend"

Change-Id: I889774c843ef5b4a7092b0e580d13ba251693f48
Reviewed-on: https://skia-review.googlesource.com/c/buildbot/+/372583
Reviewed-by: Kevin Lubick <kjlubick@google.com>
Commit-Queue: Kevin Lubick <kjlubick@google.com>
diff --git a/golden/Makefile b/golden/Makefile
index 28faa49..03b7278 100644
--- a/golden/Makefile
+++ b/golden/Makefile
@@ -64,9 +64,9 @@
 allgo:
 	go install -v ./cmd/...
 
-.PHONY: k8s-release-skiacorrectness
-k8s-release-skiacorrectness: build-static-skiacorrectness frontend
-	./k8s_release_skiacorrectness
+.PHONY: k8s-release-frontend
+k8s-release-frontend: build-static-frontend frontend
+	./k8s_release_frontend
 
 .PHONY: k8s-release-diff-server
 k8s-release-diff-server: build-static-diffserver
@@ -92,11 +92,11 @@
 k8s-release-goldpushk-crashing-server: build-static-goldpushk-crashing-server
 	./k8s_release_goldpushk_crashing_server
 
-.PHONY: build-static-skiacorrectness
-build-static-skiacorrectness: frontend
+.PHONY: build-static-frontend
+build-static-frontend: frontend
 	mkdir -p ./build
-	rm -f ./build/skiacorrectness_k8s
-	$(KGO) -o build/skiacorrectness_k8s -a ./cmd/skiacorrectness/...
+	rm -f ./build/frontend_k8s
+	$(KGO) -o build/frontend_k8s -a ./cmd/gold_frontend/...
 
 .PHONY: build-static-baseline-server
 build-static-baseline-server:
diff --git a/golden/README.md b/golden/README.md
index d1b8378..388b116 100644
--- a/golden/README.md
+++ b/golden/README.md
@@ -34,9 +34,6 @@
 artifacts like `{{.Title}}` as that's where the golang templating on the server will insert
 data.
 
-As we transition off of Polymer-based pages, there is a "page" called transitional that
-houses a wide assortment of lit-html elements that are bundled into the Polymer pages.
-
 To run the tests for these lit-html pages, run:
 
 	make js-test
@@ -49,12 +46,12 @@
 CSS and "how it looks" are presumed to be handled by a human during
 development and integration
 
-If you are running a skiacorrectness server locally, you can (in another terminal)
+If you are running the frontend server locally, you can (in another terminal)
 run
 
 	make frontend
 
-which will rebuild all the frontend pages. When in --local mode, the skiacorrectness
+which will rebuild all the frontend pages. When in --local mode, the frontend
 server will reload the templates/pages every time, so you don't have to restart it to
 see the re-built pages.
 
diff --git a/golden/cmd/skiacorrectness/BUILD.bazel b/golden/cmd/gold_frontend/BUILD.bazel
similarity index 100%
rename from golden/cmd/skiacorrectness/BUILD.bazel
rename to golden/cmd/gold_frontend/BUILD.bazel
diff --git a/golden/cmd/skiacorrectness/skiacorrectness.go b/golden/cmd/gold_frontend/gold_frontend.go
similarity index 98%
rename from golden/cmd/skiacorrectness/skiacorrectness.go
rename to golden/cmd/gold_frontend/gold_frontend.go
index f36d702..1affbeb 100644
--- a/golden/cmd/skiacorrectness/skiacorrectness.go
+++ b/golden/cmd/gold_frontend/gold_frontend.go
@@ -1,4 +1,4 @@
-// skiacorrectness implements the process that exposes a RESTful API used by the JS frontend.
+// The goldfrontend executable is the process that exposes a RESTful API used by the JS frontend.
 package main
 
 import (
@@ -227,7 +227,7 @@
 
 	diffStore := mustMakeDiffStore(ctx, fsc)
 
-	gitStore := mustMakeGitStore(ctx, fsc, appName)
+	gitStore := mustMakeGitStore(ctx, fsc, "gold-skiacorrectness") // Historical name
 
 	vcs := mustMakeVCS(ctx, fsc, gitStore)
 
diff --git a/golden/cmd/skiacorrectness/skiacorrectness_test.go b/golden/cmd/gold_frontend/gold_frontend_test.go
similarity index 100%
rename from golden/cmd/skiacorrectness/skiacorrectness_test.go
rename to golden/cmd/gold_frontend/gold_frontend_test.go
diff --git a/golden/cmd/goldpushk/goldpushk/goldpushk.go b/golden/cmd/goldpushk/goldpushk/goldpushk.go
index 1faf8b8..8d64557 100644
--- a/golden/cmd/goldpushk/goldpushk/goldpushk.go
+++ b/golden/cmd/goldpushk/goldpushk/goldpushk.go
@@ -752,7 +752,7 @@
 	//   app:gold-chrome-gpu-baselineserver  podName:gold-chrome-gpu-baselineserver-5dfd8b65cb-l4lt5  ready:True  readyLastTransitionTime:2019-10-04T01:59:40Z
 	//   app:gold-chrome-gpu-diffserver  podName:gold-chrome-gpu-diffserver-0  ready:True  readyLastTransitionTime:2019-10-09T18:43:08Z
 	//   app:gold-chrome-gpu-ingestion-bt  podName:gold-chrome-gpu-ingestion-bt-f8b66844f-4969w  ready:True  readyLastTransitionTime:2019-10-04T01:54:54Z
-	//   app:gold-chrome-gpu-skiacorrectness  podName:gold-chrome-gpu-skiacorrectness-67c547667d-cwt42  ready:True  readyLastTransitionTime:2019-10-04T02:01:11Z
+	//   app:gold-chrome-gpu-frontend  podName:gold-chrome-gpu-frontend-67c547667d-cwt42  ready:True  readyLastTransitionTime:2019-10-04T02:01:11Z
 	//
 	// The output format should be fairly self explanatory, but to see an example of where those
 	// are coming from, try running e.g. "kubectl get pod gold-skia-diffserver-0 -o json".
diff --git a/golden/cmd/goldpushk/goldpushk/goldpushk_test.go b/golden/cmd/goldpushk/goldpushk/goldpushk_test.go
index d45f40f..d9a58ca 100644
--- a/golden/cmd/goldpushk/goldpushk/goldpushk_test.go
+++ b/golden/cmd/goldpushk/goldpushk/goldpushk_test.go
@@ -23,8 +23,8 @@
 	// Gather some DeployableUnits to pass to New() as parameters.
 	s := ProductionDeployableUnits()
 	deployableUnits := []DeployableUnit{}
-	deployableUnits = appendUnit(t, deployableUnits, s, Skia, DiffServer)            // Regular deployment.
-	deployableUnits = appendUnit(t, deployableUnits, s, SkiaPublic, SkiaCorrectness) // Public deployment with non-templated ConfigMap.
+	deployableUnits = appendUnit(t, deployableUnits, s, Skia, DiffServer)     // Regular deployment.
+	deployableUnits = appendUnit(t, deployableUnits, s, SkiaPublic, Frontend) // Public deployment with non-templated ConfigMap.
 	canariedDeployableUnits := []DeployableUnit{}
 	canariedDeployableUnits = appendUnit(t, canariedDeployableUnits, s, Skia, IngestionBT)    // Regular deployment with templated ConfigMap.
 	canariedDeployableUnits = appendUnit(t, canariedDeployableUnits, s, Fuchsia, DiffServer)  // Internal deployment.
@@ -114,8 +114,8 @@
 	// Test on a good combination of different types of deployments.
 	s := ProductionDeployableUnits()
 	deployableUnits := []DeployableUnit{}
-	deployableUnits = appendUnit(t, deployableUnits, s, Skia, DiffServer)            // Regular deployment.
-	deployableUnits = appendUnit(t, deployableUnits, s, SkiaPublic, SkiaCorrectness) // Public deployment with non-templated ConfigMap.
+	deployableUnits = appendUnit(t, deployableUnits, s, Skia, DiffServer)     // Regular deployment.
+	deployableUnits = appendUnit(t, deployableUnits, s, SkiaPublic, Frontend) // Public deployment with non-templated ConfigMap.
 	canariedDeployableUnits := []DeployableUnit{}
 	canariedDeployableUnits = appendUnit(t, canariedDeployableUnits, s, Skia, IngestionBT)    // Regular deployment with templated ConfigMap.
 	canariedDeployableUnits = appendUnit(t, canariedDeployableUnits, s, Fuchsia, DiffServer)  // Internal deployment.
@@ -156,17 +156,17 @@
 			"-strict " +
 			"-o " + g.k8sConfigCheckout.Dir() + "/skia-public/gold-skia-diffserver.yaml",
 
-		// SkiaPublic SkiaCorrectness
+		// SkiaPublic Frontend
 		"kube-conf-gen " +
 			"-c /path/to/buildbot/golden/k8s-config-templates/gold-common.json5 " +
 			"-c /path/to/buildbot/golden/k8s-instances/skia-public/skia-public.json5 " +
-			"-c /path/to/buildbot/golden/k8s-instances/skia-public/skia-public-skiacorrectness.json5 " +
+			"-c /path/to/buildbot/golden/k8s-instances/skia-public/skia-public-frontend.json5 " +
 			"-extra INSTANCE_ID:skia-public " +
 			"-extra NOW:2020-07-06T05_04_03Z_00 " +
-			"-t /path/to/buildbot/golden/k8s-config-templates/gold-skiacorrectness-template.yaml " +
+			"-t /path/to/buildbot/golden/k8s-config-templates/gold-frontend-template.yaml " +
 			"-parse_conf=false " +
 			"-strict " +
-			"-o " + g.k8sConfigCheckout.Dir() + "/skia-public/gold-skia-public-skiacorrectness.yaml",
+			"-o " + g.k8sConfigCheckout.Dir() + "/skia-public/gold-skia-public-frontend.yaml",
 
 		// Skia IngestionBT
 		"kube-conf-gen " +
diff --git a/golden/cmd/goldpushk/goldpushk/services_map_test.go b/golden/cmd/goldpushk/goldpushk/services_map_test.go
index 29ab12d..d6a3922 100644
--- a/golden/cmd/goldpushk/goldpushk/services_map_test.go
+++ b/golden/cmd/goldpushk/goldpushk/services_map_test.go
@@ -51,7 +51,7 @@
 	}
 
 	for _, instance := range deployableUnitSet.knownInstances {
-		assertHasService(instance, SkiaCorrectness)
+		assertHasService(instance, Frontend)
 		if !isPublicInstance(instance) {
 			assertHasService(instance, DiffServer)
 			assertHasService(instance, IngestionBT)
diff --git a/golden/cmd/goldpushk/goldpushk/types_test.go b/golden/cmd/goldpushk/goldpushk/types_test.go
index e93d93c..d670bf4 100644
--- a/golden/cmd/goldpushk/goldpushk/types_test.go
+++ b/golden/cmd/goldpushk/goldpushk/types_test.go
@@ -169,9 +169,9 @@
 func TestDeployableUnitSetKnownServices(t *testing.T) {
 	unittest.SmallTest(t)
 	s := DeployableUnitSet{
-		knownServices: []Service{BaselineServer, DiffServer, SkiaCorrectness},
+		knownServices: []Service{BaselineServer, DiffServer, Frontend},
 	}
-	require.Equal(t, []Service{BaselineServer, DiffServer, SkiaCorrectness}, s.KnownServices())
+	require.Equal(t, []Service{BaselineServer, DiffServer, Frontend}, s.KnownServices())
 }
 
 func TestDeployableUnitSetIsKnownInstance(t *testing.T) {
@@ -188,11 +188,11 @@
 func TestDeployableUnitSetIsKnownService(t *testing.T) {
 	unittest.SmallTest(t)
 	s := DeployableUnitSet{
-		knownServices: []Service{BaselineServer, DiffServer, SkiaCorrectness},
+		knownServices: []Service{BaselineServer, DiffServer, Frontend},
 	}
 	require.True(t, s.IsKnownService(BaselineServer))
 	require.True(t, s.IsKnownService(DiffServer))
-	require.True(t, s.IsKnownService(SkiaCorrectness))
+	require.True(t, s.IsKnownService(Frontend))
 	require.False(t, s.IsKnownService(Service("foo")))
 }
 
diff --git a/golden/cmd/goldpushk/main.go b/golden/cmd/goldpushk/main.go
index 81fb004..6800618 100644
--- a/golden/cmd/goldpushk/main.go
+++ b/golden/cmd/goldpushk/main.go
@@ -93,8 +93,8 @@
 	rootCmd.Flags().SortFlags = false
 	rootCmd.Flags().BoolVar(&flagList, "list", false, "List known Gold instances and services (tip: try combining this flag with --testing).")
 	rootCmd.Flags().StringSliceVarP(&flagInstances, "instances", "i", []string{}, "[REQUIRED] Comma-delimited list of Gold instances to target (e.g. \"skia,flutter\"), or \""+all+"\" to target all instances.")
-	rootCmd.Flags().StringSliceVarP(&flagServices, "services", "s", []string{}, "[REQUIRED] Comma-delimited list of services to target (e.g. \"skiacorrectness,diffserver\"), or \""+all+"\" to target all services.")
-	rootCmd.Flags().StringSliceVarP(&flagCanaries, "canaries", "c", []string{}, "Comma-delimited subset of Gold services to use as canaries, written as instance:service pairs (e.g. \"skia:diffserver,flutter:skiacorrectness\")")
+	rootCmd.Flags().StringSliceVarP(&flagServices, "services", "s", []string{}, "[REQUIRED] Comma-delimited list of services to target (e.g. \"frontend,diffserver\"), or \""+all+"\" to target all services.")
+	rootCmd.Flags().StringSliceVarP(&flagCanaries, "canaries", "c", []string{}, "Comma-delimited subset of Gold services to use as canaries, written as instance:service pairs (e.g. \"skia:diffserver,flutter:frontend\")")
 	rootCmd.Flags().BoolVar(&flagDryRun, "dryrun", false, "Do everything except applying the new configuration to Kubernetes and committing changes to Git.")
 	rootCmd.Flags().BoolVar(&flagNoCommit, "no-commit", false, "Do not commit configuration changes to the k8s-config repository.")
 	rootCmd.Flags().IntVar(&flagMinUptimeSeconds, "min-uptime", 30, "Minimum uptime in seconds required for all services before exiting the monitoring step.")
diff --git a/golden/cmd/goldpushk/main_test.go b/golden/cmd/goldpushk/main_test.go
index ee3b015..d1a5000 100644
--- a/golden/cmd/goldpushk/main_test.go
+++ b/golden/cmd/goldpushk/main_test.go
@@ -123,35 +123,35 @@
 	unittest.SmallTest(t)
 
 	// Deployments shared among test cases.
-	angleSkiaCorrectness := makeID(goldpushk.Angle, goldpushk.SkiaCorrectness)
+	angleFrontend := makeID(goldpushk.Angle, goldpushk.Frontend)
 	angleDiffServer := makeID(goldpushk.Angle, goldpushk.DiffServer)
 	chromeBaselineServer := makeID(goldpushk.Chrome, goldpushk.BaselineServer)
 	chromeDiffCalculator := makeID(goldpushk.Chrome, goldpushk.DiffCalculator)
 	chromeDiffServer := makeID(goldpushk.Chrome, goldpushk.DiffServer)
 	chromeIngestionBT := makeID(goldpushk.Chrome, goldpushk.IngestionBT)
-	chromeSkiaCorrectness := makeID(goldpushk.Chrome, goldpushk.SkiaCorrectness)
-	chromePublicSkiaCorrectness := makeID(goldpushk.ChromePublic, goldpushk.SkiaCorrectness)
-	chromiumTastSkiaCorrectness := makeID(goldpushk.ChromiumOSTastDev, goldpushk.SkiaCorrectness)
+	chromeFrontend := makeID(goldpushk.Chrome, goldpushk.Frontend)
+	chromePublicFrontend := makeID(goldpushk.ChromePublic, goldpushk.Frontend)
+	chromiumTastFrontend := makeID(goldpushk.ChromiumOSTastDev, goldpushk.Frontend)
 	chromiumTastDiffServer := makeID(goldpushk.ChromiumOSTastDev, goldpushk.DiffServer)
 	flutterDiffServer := makeID(goldpushk.Flutter, goldpushk.DiffServer)
 	flutterEngineDiffServer := makeID(goldpushk.FlutterEngine, goldpushk.DiffServer)
-	flutterEngineSkiaCorrectness := makeID(goldpushk.FlutterEngine, goldpushk.SkiaCorrectness)
-	flutterSkiaCorrectness := makeID(goldpushk.Flutter, goldpushk.SkiaCorrectness)
+	flutterEngineFrontend := makeID(goldpushk.FlutterEngine, goldpushk.Frontend)
+	flutterFrontend := makeID(goldpushk.Flutter, goldpushk.Frontend)
 	fuchsiaDiffServer := makeID(goldpushk.Fuchsia, goldpushk.DiffServer)
 	fuchsiaPublicDiffServer := makeID(goldpushk.FuchsiaPublic, goldpushk.DiffServer)
-	fuchsiaPublicSkiaCorrectness := makeID(goldpushk.FuchsiaPublic, goldpushk.SkiaCorrectness)
-	fuchsiaSkiaCorrectness := makeID(goldpushk.Fuchsia, goldpushk.SkiaCorrectness)
+	fuchsiaPublicFrontend := makeID(goldpushk.FuchsiaPublic, goldpushk.Frontend)
+	fuchsiaFrontend := makeID(goldpushk.Fuchsia, goldpushk.Frontend)
 	lottieDiffServer := makeID(goldpushk.Lottie, goldpushk.DiffServer)
-	lottieSkiaCorrectness := makeID(goldpushk.Lottie, goldpushk.SkiaCorrectness)
+	lottieFrontend := makeID(goldpushk.Lottie, goldpushk.Frontend)
 	pdfiumDiffServer := makeID(goldpushk.Pdfium, goldpushk.DiffServer)
-	pdfiumSkiaCorrectness := makeID(goldpushk.Pdfium, goldpushk.SkiaCorrectness)
+	pdfiumFrontend := makeID(goldpushk.Pdfium, goldpushk.Frontend)
 	skiaDiffCalculator := makeID(goldpushk.Skia, goldpushk.DiffCalculator)
 	skiaDiffServer := makeID(goldpushk.Skia, goldpushk.DiffServer)
 	skiaInfraDiffServer := makeID(goldpushk.SkiaInfra, goldpushk.DiffServer)
-	skiaInfraSkiaCorrectness := makeID(goldpushk.SkiaInfra, goldpushk.SkiaCorrectness)
+	skiaInfraFrontend := makeID(goldpushk.SkiaInfra, goldpushk.Frontend)
 	skiaIngestionBT := makeID(goldpushk.Skia, goldpushk.IngestionBT)
-	skiaPublicSkiaCorrectness := makeID(goldpushk.SkiaPublic, goldpushk.SkiaCorrectness)
-	skiaSkiaCorrectness := makeID(goldpushk.Skia, goldpushk.SkiaCorrectness)
+	skiaPublicFrontend := makeID(goldpushk.SkiaPublic, goldpushk.Frontend)
+	skiaFrontend := makeID(goldpushk.Skia, goldpushk.Frontend)
 
 	test := func(name string, flagInstances, flagServices, flagCanaries []string, expectedDeployableUnitIDs, expectedCanariedDeployableUnitIDs []goldpushk.DeployableUnitID) {
 		t.Run(name, func(t *testing.T) {
@@ -175,102 +175,102 @@
 		[]goldpushk.DeployableUnitID{chromeBaselineServer, chromeDiffServer},
 		nil)
 	test("Single instance, multiple services, one canary",
-		[]string{"chrome"}, []string{"baselineserver", "diffserver", "skiacorrectness"}, []string{"chrome:skiacorrectness"},
+		[]string{"chrome"}, []string{"baselineserver", "diffserver", "frontend"}, []string{"chrome:frontend"},
 		[]goldpushk.DeployableUnitID{chromeBaselineServer, chromeDiffServer},
-		[]goldpushk.DeployableUnitID{chromeSkiaCorrectness})
+		[]goldpushk.DeployableUnitID{chromeFrontend})
 	test("Single instance, multiple services, multiple canaries",
-		[]string{"chrome"}, []string{"baselineserver", "diffserver", "skiacorrectness"}, []string{"chrome:diffserver", "chrome:skiacorrectness"},
+		[]string{"chrome"}, []string{"baselineserver", "diffserver", "frontend"}, []string{"chrome:diffserver", "chrome:frontend"},
 		[]goldpushk.DeployableUnitID{chromeBaselineServer},
-		[]goldpushk.DeployableUnitID{chromeDiffServer, chromeSkiaCorrectness})
+		[]goldpushk.DeployableUnitID{chromeDiffServer, chromeFrontend})
 	test("Multiple instances, single service, no canary",
-		[]string{"chrome", "skia", "skia-public"}, []string{"skiacorrectness"}, nil,
-		[]goldpushk.DeployableUnitID{chromeSkiaCorrectness, skiaSkiaCorrectness, skiaPublicSkiaCorrectness},
+		[]string{"chrome", "skia", "skia-public"}, []string{"frontend"}, nil,
+		[]goldpushk.DeployableUnitID{chromeFrontend, skiaFrontend, skiaPublicFrontend},
 		nil)
 	test("Multiple instances, single service, one canary",
-		[]string{"chrome", "skia", "skia-public"}, []string{"skiacorrectness"}, []string{"skia-public:skiacorrectness"},
-		[]goldpushk.DeployableUnitID{chromeSkiaCorrectness, skiaSkiaCorrectness},
-		[]goldpushk.DeployableUnitID{skiaPublicSkiaCorrectness})
+		[]string{"chrome", "skia", "skia-public"}, []string{"frontend"}, []string{"skia-public:frontend"},
+		[]goldpushk.DeployableUnitID{chromeFrontend, skiaFrontend},
+		[]goldpushk.DeployableUnitID{skiaPublicFrontend})
 	test("Multiple instances, single service, multiple canaries",
-		[]string{"chrome", "skia", "skia-public"}, []string{"skiacorrectness"}, []string{"skia:skiacorrectness", "skia-public:skiacorrectness"},
-		[]goldpushk.DeployableUnitID{chromeSkiaCorrectness},
-		[]goldpushk.DeployableUnitID{skiaSkiaCorrectness, skiaPublicSkiaCorrectness})
+		[]string{"chrome", "skia", "skia-public"}, []string{"frontend"}, []string{"skia:frontend", "skia-public:frontend"},
+		[]goldpushk.DeployableUnitID{chromeFrontend},
+		[]goldpushk.DeployableUnitID{skiaFrontend, skiaPublicFrontend})
 	test("Multiple instances, multiple services, no canary",
-		[]string{"chrome", "skia", "skia-public"}, []string{"diffserver", "skiacorrectness"}, nil,
-		[]goldpushk.DeployableUnitID{chromeDiffServer, chromeSkiaCorrectness, skiaDiffServer, skiaSkiaCorrectness, skiaPublicSkiaCorrectness},
+		[]string{"chrome", "skia", "skia-public"}, []string{"diffserver", "frontend"}, nil,
+		[]goldpushk.DeployableUnitID{chromeDiffServer, chromeFrontend, skiaDiffServer, skiaFrontend, skiaPublicFrontend},
 		nil)
 	test("Multiple instances, multiple services, one canary",
-		[]string{"chrome", "skia", "skia-public"}, []string{"diffserver", "skiacorrectness"}, []string{"skia-public:skiacorrectness"},
-		[]goldpushk.DeployableUnitID{chromeDiffServer, chromeSkiaCorrectness, skiaDiffServer, skiaSkiaCorrectness},
-		[]goldpushk.DeployableUnitID{skiaPublicSkiaCorrectness})
+		[]string{"chrome", "skia", "skia-public"}, []string{"diffserver", "frontend"}, []string{"skia-public:frontend"},
+		[]goldpushk.DeployableUnitID{chromeDiffServer, chromeFrontend, skiaDiffServer, skiaFrontend},
+		[]goldpushk.DeployableUnitID{skiaPublicFrontend})
 	test("Multiple instances, multiple services, multiple canaries",
-		[]string{"chrome", "skia", "skia-public"}, []string{"diffserver", "skiacorrectness"}, []string{"skia:skiacorrectness", "skia-public:skiacorrectness"},
-		[]goldpushk.DeployableUnitID{chromeDiffServer, chromeSkiaCorrectness, skiaDiffServer},
-		[]goldpushk.DeployableUnitID{skiaSkiaCorrectness, skiaPublicSkiaCorrectness})
+		[]string{"chrome", "skia", "skia-public"}, []string{"diffserver", "frontend"}, []string{"skia:frontend", "skia-public:frontend"},
+		[]goldpushk.DeployableUnitID{chromeDiffServer, chromeFrontend, skiaDiffServer},
+		[]goldpushk.DeployableUnitID{skiaFrontend, skiaPublicFrontend})
 
 	////////////////////////////////////////////////////////////////////////////////////////////////
 	// Wildcard: --service all                                                                    //
 	////////////////////////////////////////////////////////////////////////////////////////////////
 	test("Single instance, all services, no canary",
 		[]string{"chrome"}, []string{"all"}, nil,
-		[]goldpushk.DeployableUnitID{chromeBaselineServer, chromeDiffCalculator, chromeDiffServer, chromeIngestionBT, chromeSkiaCorrectness},
+		[]goldpushk.DeployableUnitID{chromeBaselineServer, chromeDiffCalculator, chromeDiffServer, chromeIngestionBT, chromeFrontend},
 		nil)
 	test("Single instance, all services, one canary",
-		[]string{"chrome"}, []string{"all"}, []string{"chrome:skiacorrectness"},
+		[]string{"chrome"}, []string{"all"}, []string{"chrome:frontend"},
 		[]goldpushk.DeployableUnitID{chromeBaselineServer, chromeDiffCalculator, chromeDiffServer, chromeIngestionBT},
-		[]goldpushk.DeployableUnitID{chromeSkiaCorrectness})
+		[]goldpushk.DeployableUnitID{chromeFrontend})
 	test("Single instance, all services, multiple canaries",
-		[]string{"chrome"}, []string{"all"}, []string{"chrome:ingestion-bt", "chrome:skiacorrectness"},
+		[]string{"chrome"}, []string{"all"}, []string{"chrome:ingestion-bt", "chrome:frontend"},
 		[]goldpushk.DeployableUnitID{chromeBaselineServer, chromeDiffCalculator, chromeDiffServer},
-		[]goldpushk.DeployableUnitID{chromeIngestionBT, chromeSkiaCorrectness})
+		[]goldpushk.DeployableUnitID{chromeIngestionBT, chromeFrontend})
 	test("Multiple instances, all services, no canary",
 		[]string{"chrome", "skia"}, []string{"all"}, nil,
-		[]goldpushk.DeployableUnitID{chromeBaselineServer, chromeDiffCalculator, chromeDiffServer, chromeIngestionBT, chromeSkiaCorrectness, skiaDiffCalculator, skiaDiffServer, skiaIngestionBT, skiaSkiaCorrectness},
+		[]goldpushk.DeployableUnitID{chromeBaselineServer, chromeDiffCalculator, chromeDiffServer, chromeIngestionBT, chromeFrontend, skiaDiffCalculator, skiaDiffServer, skiaIngestionBT, skiaFrontend},
 		nil)
 	test("Multiple instances, all services, one canary",
-		[]string{"chrome", "skia"}, []string{"all"}, []string{"skia:skiacorrectness"},
-		[]goldpushk.DeployableUnitID{chromeBaselineServer, chromeDiffCalculator, chromeDiffServer, chromeIngestionBT, chromeSkiaCorrectness, skiaDiffCalculator, skiaDiffServer, skiaIngestionBT},
-		[]goldpushk.DeployableUnitID{skiaSkiaCorrectness})
+		[]string{"chrome", "skia"}, []string{"all"}, []string{"skia:frontend"},
+		[]goldpushk.DeployableUnitID{chromeBaselineServer, chromeDiffCalculator, chromeDiffServer, chromeIngestionBT, chromeFrontend, skiaDiffCalculator, skiaDiffServer, skiaIngestionBT},
+		[]goldpushk.DeployableUnitID{skiaFrontend})
 	test("Multiple instances, all services, multiple canaries",
-		[]string{"chrome", "skia"}, []string{"all"}, []string{"skia:ingestion-bt", "skia:skiacorrectness"},
-		[]goldpushk.DeployableUnitID{chromeBaselineServer, chromeDiffCalculator, chromeDiffServer, chromeIngestionBT, chromeSkiaCorrectness, skiaDiffCalculator, skiaDiffServer},
-		[]goldpushk.DeployableUnitID{skiaIngestionBT, skiaSkiaCorrectness})
+		[]string{"chrome", "skia"}, []string{"all"}, []string{"skia:ingestion-bt", "skia:frontend"},
+		[]goldpushk.DeployableUnitID{chromeBaselineServer, chromeDiffCalculator, chromeDiffServer, chromeIngestionBT, chromeFrontend, skiaDiffCalculator, skiaDiffServer},
+		[]goldpushk.DeployableUnitID{skiaIngestionBT, skiaFrontend})
 
 	////////////////////////////////////////////////////////////////////////////////////////////////
 	// Wildcard: --instance all                                                                   //
 	////////////////////////////////////////////////////////////////////////////////////////////////
 	test("All instances, single service, no canary",
-		[]string{"all"}, []string{"skiacorrectness"}, nil,
-		[]goldpushk.DeployableUnitID{angleSkiaCorrectness, chromeSkiaCorrectness, chromePublicSkiaCorrectness, chromiumTastSkiaCorrectness, flutterSkiaCorrectness, flutterEngineSkiaCorrectness, fuchsiaSkiaCorrectness, fuchsiaPublicSkiaCorrectness, lottieSkiaCorrectness, pdfiumSkiaCorrectness, skiaSkiaCorrectness, skiaInfraSkiaCorrectness, skiaPublicSkiaCorrectness},
+		[]string{"all"}, []string{"frontend"}, nil,
+		[]goldpushk.DeployableUnitID{angleFrontend, chromeFrontend, chromePublicFrontend, chromiumTastFrontend, flutterFrontend, flutterEngineFrontend, fuchsiaFrontend, fuchsiaPublicFrontend, lottieFrontend, pdfiumFrontend, skiaFrontend, skiaInfraFrontend, skiaPublicFrontend},
 		nil)
 	test("All instances, single service, one canary",
-		[]string{"all"}, []string{"skiacorrectness"}, []string{"skia-public:skiacorrectness"},
-		[]goldpushk.DeployableUnitID{angleSkiaCorrectness, chromeSkiaCorrectness, chromePublicSkiaCorrectness, chromiumTastSkiaCorrectness, flutterSkiaCorrectness, flutterEngineSkiaCorrectness, fuchsiaSkiaCorrectness, fuchsiaPublicSkiaCorrectness, lottieSkiaCorrectness, pdfiumSkiaCorrectness, skiaSkiaCorrectness, skiaInfraSkiaCorrectness},
-		[]goldpushk.DeployableUnitID{skiaPublicSkiaCorrectness})
+		[]string{"all"}, []string{"frontend"}, []string{"skia-public:frontend"},
+		[]goldpushk.DeployableUnitID{angleFrontend, chromeFrontend, chromePublicFrontend, chromiumTastFrontend, flutterFrontend, flutterEngineFrontend, fuchsiaFrontend, fuchsiaPublicFrontend, lottieFrontend, pdfiumFrontend, skiaFrontend, skiaInfraFrontend},
+		[]goldpushk.DeployableUnitID{skiaPublicFrontend})
 	test("All instances, single service, multiple canaries",
-		[]string{"all"}, []string{"skiacorrectness"}, []string{"skia-infra:skiacorrectness", "skia-public:skiacorrectness"},
-		[]goldpushk.DeployableUnitID{angleSkiaCorrectness, chromeSkiaCorrectness, chromePublicSkiaCorrectness, chromiumTastSkiaCorrectness, flutterSkiaCorrectness, flutterEngineSkiaCorrectness, fuchsiaSkiaCorrectness, fuchsiaPublicSkiaCorrectness, lottieSkiaCorrectness, pdfiumSkiaCorrectness, skiaSkiaCorrectness},
-		[]goldpushk.DeployableUnitID{skiaInfraSkiaCorrectness, skiaPublicSkiaCorrectness})
+		[]string{"all"}, []string{"frontend"}, []string{"skia-infra:frontend", "skia-public:frontend"},
+		[]goldpushk.DeployableUnitID{angleFrontend, chromeFrontend, chromePublicFrontend, chromiumTastFrontend, flutterFrontend, flutterEngineFrontend, fuchsiaFrontend, fuchsiaPublicFrontend, lottieFrontend, pdfiumFrontend, skiaFrontend},
+		[]goldpushk.DeployableUnitID{skiaInfraFrontend, skiaPublicFrontend})
 	test("All instances, multiple services, no canary",
-		[]string{"all"}, []string{"diffserver", "skiacorrectness"}, nil,
-		[]goldpushk.DeployableUnitID{angleSkiaCorrectness, angleDiffServer, chromeDiffServer, chromeSkiaCorrectness, chromePublicSkiaCorrectness, chromiumTastDiffServer, chromiumTastSkiaCorrectness, flutterDiffServer, flutterSkiaCorrectness, flutterEngineDiffServer, flutterEngineSkiaCorrectness, fuchsiaDiffServer, fuchsiaSkiaCorrectness, fuchsiaPublicDiffServer, fuchsiaPublicSkiaCorrectness, lottieDiffServer, lottieSkiaCorrectness, pdfiumDiffServer, pdfiumSkiaCorrectness, skiaDiffServer, skiaSkiaCorrectness, skiaInfraDiffServer, skiaInfraSkiaCorrectness, skiaPublicSkiaCorrectness},
+		[]string{"all"}, []string{"diffserver", "frontend"}, nil,
+		[]goldpushk.DeployableUnitID{angleFrontend, angleDiffServer, chromeDiffServer, chromeFrontend, chromePublicFrontend, chromiumTastDiffServer, chromiumTastFrontend, flutterDiffServer, flutterFrontend, flutterEngineDiffServer, flutterEngineFrontend, fuchsiaDiffServer, fuchsiaFrontend, fuchsiaPublicDiffServer, fuchsiaPublicFrontend, lottieDiffServer, lottieFrontend, pdfiumDiffServer, pdfiumFrontend, skiaDiffServer, skiaFrontend, skiaInfraDiffServer, skiaInfraFrontend, skiaPublicFrontend},
 		nil)
 	test("All instances, multiple services, one canary",
-		[]string{"all"}, []string{"diffserver", "skiacorrectness"}, []string{"skia-public:skiacorrectness"},
-		[]goldpushk.DeployableUnitID{angleSkiaCorrectness, angleDiffServer, chromeDiffServer, chromeSkiaCorrectness, chromePublicSkiaCorrectness, chromiumTastDiffServer, chromiumTastSkiaCorrectness, flutterDiffServer, flutterSkiaCorrectness, flutterEngineDiffServer, flutterEngineSkiaCorrectness, fuchsiaDiffServer, fuchsiaSkiaCorrectness, fuchsiaPublicDiffServer, fuchsiaPublicSkiaCorrectness, lottieDiffServer, lottieSkiaCorrectness, pdfiumDiffServer, pdfiumSkiaCorrectness, skiaDiffServer, skiaSkiaCorrectness, skiaInfraDiffServer, skiaInfraSkiaCorrectness},
-		[]goldpushk.DeployableUnitID{skiaPublicSkiaCorrectness})
+		[]string{"all"}, []string{"diffserver", "frontend"}, []string{"skia-public:frontend"},
+		[]goldpushk.DeployableUnitID{angleFrontend, angleDiffServer, chromeDiffServer, chromeFrontend, chromePublicFrontend, chromiumTastDiffServer, chromiumTastFrontend, flutterDiffServer, flutterFrontend, flutterEngineDiffServer, flutterEngineFrontend, fuchsiaDiffServer, fuchsiaFrontend, fuchsiaPublicDiffServer, fuchsiaPublicFrontend, lottieDiffServer, lottieFrontend, pdfiumDiffServer, pdfiumFrontend, skiaDiffServer, skiaFrontend, skiaInfraDiffServer, skiaInfraFrontend},
+		[]goldpushk.DeployableUnitID{skiaPublicFrontend})
 
 	////////////////////////////////////////////////////////////////////////////////////////////////
 	// Miscellaneous                                                                              //
 	////////////////////////////////////////////////////////////////////////////////////////////////
 
 	test("Repeated inputs are ignored",
-		[]string{"chrome", "chrome", "skia", "chrome", "skia", "skia-public", "skia-public"}, []string{"diffserver", "skiacorrectness", "diffserver", "skiacorrectness"}, []string{"skia:diffserver", "skia-public:skiacorrectness", "skia:diffserver", "skia-public:skiacorrectness"},
-		[]goldpushk.DeployableUnitID{chromeDiffServer, chromeSkiaCorrectness, skiaSkiaCorrectness},
-		[]goldpushk.DeployableUnitID{skiaDiffServer, skiaPublicSkiaCorrectness})
+		[]string{"chrome", "chrome", "skia", "chrome", "skia", "skia-public", "skia-public"}, []string{"diffserver", "frontend", "diffserver", "frontend"}, []string{"skia:diffserver", "skia-public:frontend", "skia:diffserver", "skia-public:frontend"},
+		[]goldpushk.DeployableUnitID{chromeDiffServer, chromeFrontend, skiaFrontend},
+		[]goldpushk.DeployableUnitID{skiaDiffServer, skiaPublicFrontend})
 	test("Outputs sorted by instance, then service",
-		[]string{"skia-public", "chrome", "skia"}, []string{"skiacorrectness", "diffserver"}, []string{"skia-public:skiacorrectness", "skia:diffserver"},
-		[]goldpushk.DeployableUnitID{chromeDiffServer, chromeSkiaCorrectness, skiaSkiaCorrectness},
-		[]goldpushk.DeployableUnitID{skiaDiffServer, skiaPublicSkiaCorrectness})
+		[]string{"skia-public", "chrome", "skia"}, []string{"frontend", "diffserver"}, []string{"skia-public:frontend", "skia:diffserver"},
+		[]goldpushk.DeployableUnitID{chromeDiffServer, chromeFrontend, skiaFrontend},
+		[]goldpushk.DeployableUnitID{skiaDiffServer, skiaPublicFrontend})
 }
 
 func TestParseAndValidateFlagsTestingSuccess(t *testing.T) {
diff --git a/golden/cmd/skia_diff_server/skia_diff_server.go b/golden/cmd/skia_diff_server/skia_diff_server.go
index 014a39a..513f90d 100644
--- a/golden/cmd/skia_diff_server/skia_diff_server.go
+++ b/golden/cmd/skia_diff_server/skia_diff_server.go
@@ -34,7 +34,7 @@
 	// The GCS prefix (directory) that holds the images that have been uploaded to Gold.
 	GCSImageDir string `json:"gcs_image_dir"`
 
-	// The port on which to run the GRPC service. The skiacorrectness binary will connect to this
+	// The port on which to run the GRPC service. The frontend binary will connect to this
 	// server over this port, for example.
 	GRPCPort string `json:"grpc_port"`
 
diff --git a/golden/dockerfiles/Dockerfile_frontend b/golden/dockerfiles/Dockerfile_frontend
new file mode 100644
index 0000000..b800aca
--- /dev/null
+++ b/golden/dockerfiles/Dockerfile_frontend
@@ -0,0 +1,9 @@
+FROM gcr.io/skia-public/basealpine:3.8
+
+USER root
+
+COPY . /
+
+USER skia
+
+ENTRYPOINT ["/usr/local/bin/gold-frontend"]
diff --git a/golden/dockerfiles/Dockerfile_skiacorrectness b/golden/dockerfiles/Dockerfile_skiacorrectness
deleted file mode 100644
index e899c2f..0000000
--- a/golden/dockerfiles/Dockerfile_skiacorrectness
+++ /dev/null
@@ -1,9 +0,0 @@
-FROM gcr.io/skia-public/basealpine:3.8
-
-USER root
-
-COPY . /
-
-USER skia
-
-ENTRYPOINT ["/usr/local/bin/gold-skiacorrectness"]
diff --git a/golden/docs/PROD.md b/golden/docs/PROD.md
index 9f3e878..f96ce31 100644
--- a/golden/docs/PROD.md
+++ b/golden/docs/PROD.md
@@ -39,7 +39,7 @@
 ============
 Logs for Gold instances in skia-public/skia-corp are in the usual
 GKE container grouping, for example:
-<https://console.cloud.google.com/logs/viewer?project=skia-public&resource=container&logName=projects%2Fskia-public%2Flogs%2Fgold-flutter-skiacorrectness>
+<https://console.cloud.google.com/logs/viewer?project=skia-public&resource=container&logName=projects%2Fskia-public%2Flogs%2Fgold-flutter-frontend>
 
 Opencensus Tracing
 ==================
@@ -270,7 +270,7 @@
 Gold hasn't been able to go through all the open CLs that have produced data and decide whether
 to comment on them or not in a while. The presence of this alert might mean we are seeing errors
  when talking to Firestore or to the Code Review System (CRS). Check the logs on that pod's
-frontend server (skiacorrectness) to see what's up.
+frontend server to see what's up.
 
 This might mean we are doing too much and running out of quota to talk to the CRS.  Usually
 out of quota messages will be in the error messages or the bodies of the failing requests.
diff --git a/golden/docs/README.md b/golden/docs/README.md
index cba5e8e..81fd378 100644
--- a/golden/docs/README.md
+++ b/golden/docs/README.md
@@ -34,6 +34,8 @@
 Otherwise, you'll need approximately the following steps. We use Google Cloud and Kubernetes (k8s)
 and the following assumes you do too.
 
+TODO(kjlubick) update this to handle diffcalculator
+
  1. Create a Google Cloud Project - this will house the data, credentials, configuration, and
     k8s pods that make up Gold.
  2. Make a Google Cloud Storage (GCS) bucket in the project. This specifically will be the source
@@ -46,7 +48,7 @@
     and the templates we use for deployments are in ../k8s-config-templates.
  5. Create a k8s deployment of diffserver. This will compute the differences between images
     and output things like the diff metrics and images visualizing the differences.
- 6. Create a k8s deployment of skiacorrectness. This is the main frontend server.
+ 6. Create a k8s deployment of frontend.
  7. Create a k8s deployment of baselineserver. This is a lighter-weight and more highly-available
     subset of the frontend, which will be queried by goldctl.
 
diff --git a/golden/k8s-config-templates/gold-common.json5 b/golden/k8s-config-templates/gold-common.json5
index b64a4a9..3e74e85 100644
--- a/golden/k8s-config-templates/gold-common.json5
+++ b/golden/k8s-config-templates/gold-common.json5
@@ -2,8 +2,8 @@
     "BASELINE_SERVER_IMAGE": "gcr.io/skia-public/gold-baseline-server:2021-02-22T12_37_36Z-kjlubick-d23f6c7-clean",
     "DIFFCALCULATOR_IMAGE":  "gcr.io/skia-public/gold-diffcalculator:2021-02-22T12_23_04Z-kjlubick-d23f6c7-clean",
     "DIFF_SERVER_IMAGE":     "gcr.io/skia-public/gold-diff-server:2021-01-19T14_27_42Z-kjlubick-450bea3-clean",
+    "FRONTEND_IMAGE":        "gcr.io/skia-public/gold-frontend:2021-02-22T14_57_55Z-kjlubick-83959fa-dirty",
     "INGESTION_BT_IMAGE":    "gcr.io/skia-public/gold-ingestion:2021-02-15T14_17_39Z-kjlubick-b37d281-clean",
-    "SKIACORRECTNESS_IMAGE": "gcr.io/skia-public/gold-skiacorrectness:2021-02-22T12_24_03Z-kjlubick-d23f6c7-clean",
 
     // Services for testing goldpushk.
     "HEALTHY_SERVER_IMAGE": "gcr.io/skia-public/goldpushk-healthy-server:2019-10-16T18_39_09Z-lovisolo-9b77357-clean",
diff --git a/golden/k8s-config-templates/gold-skiacorrectness-template.yaml b/golden/k8s-config-templates/gold-frontend-template.yaml
similarity index 86%
rename from golden/k8s-config-templates/gold-skiacorrectness-template.yaml
rename to golden/k8s-config-templates/gold-frontend-template.yaml
index 39aa5b5..e7596f7 100644
--- a/golden/k8s-config-templates/gold-skiacorrectness-template.yaml
+++ b/golden/k8s-config-templates/gold-frontend-template.yaml
@@ -1,7 +1,7 @@
 apiVersion: v1
 kind: Service
 metadata:
-  name: gold-{{.INSTANCE_ID}}-skiacorrectness
+  name: gold-{{.INSTANCE_ID}}-frontend
   annotations:
     beta.cloud.google.com/backend-config: '{"ports": {"8000":"skia-default-backendconfig"}}'
 spec:
@@ -11,24 +11,24 @@
     - name: metrics
       port: 20000
   selector:
-    app: gold-{{.INSTANCE_ID}}-skiacorrectness
+    app: gold-{{.INSTANCE_ID}}-frontend
   type: NodePort
 ---
 apiVersion: apps/v1
 kind: Deployment
 metadata:
-  name: gold-{{.INSTANCE_ID}}-skiacorrectness
+  name: gold-{{.INSTANCE_ID}}-frontend
 spec:
   replicas: 1
   selector:
     matchLabels:
-      app: gold-{{.INSTANCE_ID}}-skiacorrectness
+      app: gold-{{.INSTANCE_ID}}-frontend
   strategy:
     type: RollingUpdate
   template:
     metadata:
       labels:
-        app: gold-{{.INSTANCE_ID}}-skiacorrectness
+        app: gold-{{.INSTANCE_ID}}-frontend
         appgroup: gold-{{.INSTANCE_ID}}
         date: "{{.NOW}}" # Forces a re-deploy even if just the config file changes.
       annotations:
@@ -40,11 +40,11 @@
         runAsUser: 2000 # aka skia
         fsGroup: 2000   # aka skia
       containers:
-        - name: gold-{{.INSTANCE_ID}}-skiacorrectness
-          image: {{.SKIACORRECTNESS_IMAGE}}
+        - name: gold-{{.INSTANCE_ID}}-frontend
+          image: {{.FRONTEND_IMAGE}}
           args:
             - "--common_instance_config=/etc/gold-config/{{.INSTANCE_ID}}.json5"
-            - "--config=/etc/gold-config/{{.INSTANCE_ID}}-skiacorrectness.json5"
+            - "--config=/etc/gold-config/{{.INSTANCE_ID}}-frontend.json5"
             - "--logtostderr"
           ports:
             - containerPort: 8000
diff --git a/golden/k8s-instances/angle/angle-skiacorrectness.json5 b/golden/k8s-instances/angle/angle-frontend.json5
similarity index 94%
rename from golden/k8s-instances/angle/angle-skiacorrectness.json5
rename to golden/k8s-instances/angle/angle-frontend.json5
index e69d96c..f3ab3ba 100644
--- a/golden/k8s-instances/angle/angle-skiacorrectness.json5
+++ b/golden/k8s-instances/angle/angle-frontend.json5
@@ -18,7 +18,7 @@
   num_commits: 512,
   port: ":8000",
   prom_port: ":20000",
-  resources_path: "/usr/local/share/skiacorrectness/dist",
+  resources_path: "/usr/local/share/frontend/dist",
   site_url: "https://angle-gold.skia.org",
   tile_freshness: "1m",
   trace_bt_table: "gold-angle",
diff --git a/golden/k8s-instances/chrome-public/chrome-public-skiacorrectness.json5 b/golden/k8s-instances/chrome-public/chrome-public-frontend.json5
similarity index 96%
rename from golden/k8s-instances/chrome-public/chrome-public-skiacorrectness.json5
rename to golden/k8s-instances/chrome-public/chrome-public-frontend.json5
index 40d1a54..533cbec 100644
--- a/golden/k8s-instances/chrome-public/chrome-public-skiacorrectness.json5
+++ b/golden/k8s-instances/chrome-public/chrome-public-frontend.json5
@@ -17,7 +17,7 @@
   num_commits: 512,
   port: ":8000",
   prom_port: ":20000",
-  resources_path: "/usr/local/share/skiacorrectness/dist",
+  resources_path: "/usr/local/share/frontend/dist",
   site_url: "https://chrome-public-gold.skia.org",
   tile_freshness: "1m",
   trace_bt_table: "gold-chrome",
diff --git a/golden/k8s-instances/chrome/chrome-skiacorrectness.json5 b/golden/k8s-instances/chrome/chrome-frontend.json5
similarity index 96%
rename from golden/k8s-instances/chrome/chrome-skiacorrectness.json5
rename to golden/k8s-instances/chrome/chrome-frontend.json5
index 301fdbe..7fea245 100644
--- a/golden/k8s-instances/chrome/chrome-skiacorrectness.json5
+++ b/golden/k8s-instances/chrome/chrome-frontend.json5
@@ -26,7 +26,7 @@
   port: ":8000",
   prom_port: ":20000",
   public_site_url: "https://chrome-public-gold.skia.org",
-  resources_path: "/usr/local/share/skiacorrectness/dist",
+  resources_path: "/usr/local/share/frontend/dist",
   site_url: "https://chrome-gold.skia.org",
   tile_freshness: "1m",
   trace_bt_table: "gold-chrome",
diff --git a/golden/k8s-instances/cros-tast-dev/cros-tast-dev-skiacorrectness.json5 b/golden/k8s-instances/cros-tast-dev/cros-tast-dev-frontend.json5
similarity index 94%
rename from golden/k8s-instances/cros-tast-dev/cros-tast-dev-skiacorrectness.json5
rename to golden/k8s-instances/cros-tast-dev/cros-tast-dev-frontend.json5
index 6065c19..c3a7e6b 100644
--- a/golden/k8s-instances/cros-tast-dev/cros-tast-dev-skiacorrectness.json5
+++ b/golden/k8s-instances/cros-tast-dev/cros-tast-dev-frontend.json5
@@ -18,7 +18,7 @@
   num_commits: 512,
   port: ":8000",
   prom_port: ":20000",
-  resources_path: "/usr/local/share/skiacorrectness/dist",
+  resources_path: "/usr/local/share/frontend/dist",
   site_url: "https://cros-tast-dev-gold.skia.org",
   tile_freshness: "1m",
   trace_bt_table: "gold-cros-tast-dev",
diff --git a/golden/k8s-instances/flutter-engine/flutter-engine-skiacorrectness.json5 b/golden/k8s-instances/flutter-engine/flutter-engine-frontend.json5
similarity index 93%
rename from golden/k8s-instances/flutter-engine/flutter-engine-skiacorrectness.json5
rename to golden/k8s-instances/flutter-engine/flutter-engine-frontend.json5
index 611e261..feb9c01 100644
--- a/golden/k8s-instances/flutter-engine/flutter-engine-skiacorrectness.json5
+++ b/golden/k8s-instances/flutter-engine/flutter-engine-frontend.json5
@@ -16,7 +16,7 @@
   num_commits: 200,
   port: ":8000",
   prom_port: ":20000",
-  resources_path: "/usr/local/share/skiacorrectness/dist",
+  resources_path: "/usr/local/share/frontend/dist",
   site_url: "https://flutter-engine-gold.skia.org",
   tile_freshness: "1m",
   trace_bt_table: "gold-flutter-engine",
diff --git a/golden/k8s-instances/flutter/flutter-skiacorrectness.json5 b/golden/k8s-instances/flutter/flutter-frontend.json5
similarity index 94%
rename from golden/k8s-instances/flutter/flutter-skiacorrectness.json5
rename to golden/k8s-instances/flutter/flutter-frontend.json5
index dd7d6e4..83acbe2 100644
--- a/golden/k8s-instances/flutter/flutter-skiacorrectness.json5
+++ b/golden/k8s-instances/flutter/flutter-frontend.json5
@@ -19,7 +19,7 @@
   num_commits: 200,
   port: ":8000",
   prom_port: ":20000",
-  resources_path: "/usr/local/share/skiacorrectness/dist",
+  resources_path: "/usr/local/share/frontend/dist",
   site_url: "https://flutter-gold.skia.org",
   tile_freshness: "1m",
   trace_bt_table: "gold-flutter",
diff --git a/golden/k8s-instances/fuchsia-public/fuchsia-public-skiacorrectness.json5 b/golden/k8s-instances/fuchsia-public/fuchsia-public-frontend.json5
similarity index 93%
rename from golden/k8s-instances/fuchsia-public/fuchsia-public-skiacorrectness.json5
rename to golden/k8s-instances/fuchsia-public/fuchsia-public-frontend.json5
index 192400d..4b12e88 100644
--- a/golden/k8s-instances/fuchsia-public/fuchsia-public-skiacorrectness.json5
+++ b/golden/k8s-instances/fuchsia-public/fuchsia-public-frontend.json5
@@ -17,7 +17,7 @@
   num_commits: 200,
   port: ":8000",
   prom_port: ":20000",
-  resources_path: "/usr/local/share/skiacorrectness/dist",
+  resources_path: "/usr/local/share/frontend/dist",
   site_url: "https://fuchsia-public-gold.skia.org",
   tile_freshness: "1m",
   trace_bt_table: "gold-fuchsia-public",
diff --git a/golden/k8s-instances/lottie/lottie-skiacorrectness.json5 b/golden/k8s-instances/lottie/lottie-frontend.json5
similarity index 93%
rename from golden/k8s-instances/lottie/lottie-skiacorrectness.json5
rename to golden/k8s-instances/lottie/lottie-frontend.json5
index 5c7ddb0..44fa917 100644
--- a/golden/k8s-instances/lottie/lottie-skiacorrectness.json5
+++ b/golden/k8s-instances/lottie/lottie-frontend.json5
@@ -16,7 +16,7 @@
   num_commits: 500,
   port: ":8000",
   prom_port: ":20000",
-  resources_path: "/usr/local/share/skiacorrectness/dist",
+  resources_path: "/usr/local/share/frontend/dist",
   site_url: "https://lottie-gold.skia.org",
   tile_freshness: "1m",
   trace_bt_table: "gold-lottie",
diff --git a/golden/k8s-instances/pdfium/pdfium-skiacorrectness.json5 b/golden/k8s-instances/pdfium/pdfium-frontend.json5
similarity index 93%
rename from golden/k8s-instances/pdfium/pdfium-skiacorrectness.json5
rename to golden/k8s-instances/pdfium/pdfium-frontend.json5
index 4706a8f..87fb5cd 100644
--- a/golden/k8s-instances/pdfium/pdfium-skiacorrectness.json5
+++ b/golden/k8s-instances/pdfium/pdfium-frontend.json5
@@ -16,7 +16,7 @@
   num_commits: 500,
   port: ":8000",
   prom_port: ":20000",
-  resources_path: "/usr/local/share/skiacorrectness/dist",
+  resources_path: "/usr/local/share/frontend/dist",
   site_url: "https://pdfium-gold.skia.org",
   tile_freshness: "1m",
   trace_bt_table: "gold-pdfium",
diff --git a/golden/k8s-instances/skia-infra/skia-infra-skiacorrectness.json5 b/golden/k8s-instances/skia-infra/skia-infra-frontend.json5
similarity index 94%
rename from golden/k8s-instances/skia-infra/skia-infra-skiacorrectness.json5
rename to golden/k8s-instances/skia-infra/skia-infra-frontend.json5
index 1132681..1f0365f 100644
--- a/golden/k8s-instances/skia-infra/skia-infra-skiacorrectness.json5
+++ b/golden/k8s-instances/skia-infra/skia-infra-frontend.json5
@@ -18,7 +18,7 @@
   port: ":8000",
   positives_max_age: "720h", // 30 days
   prom_port: ":20000",
-  resources_path: "/usr/local/share/skiacorrectness/dist",
+  resources_path: "/usr/local/share/frontend/dist",
   site_url: "https://skia-infra-gold.skia.org",
   tile_freshness: "1m",
   trace_bt_table: "gold-skia-infra",
diff --git a/golden/k8s-instances/skia-public/skia-public-skiacorrectness.json5 b/golden/k8s-instances/skia-public/skia-public-frontend.json5
similarity index 98%
rename from golden/k8s-instances/skia-public/skia-public-skiacorrectness.json5
rename to golden/k8s-instances/skia-public/skia-public-frontend.json5
index 35b9c63..128d537 100644
--- a/golden/k8s-instances/skia-public/skia-public-skiacorrectness.json5
+++ b/golden/k8s-instances/skia-public/skia-public-frontend.json5
@@ -19,7 +19,7 @@
   num_commits: 256,
   port: ":8000",
   prom_port: ":20000",
-  resources_path: "/usr/local/share/skiacorrectness/dist",
+  resources_path: "/usr/local/share/frontend/dist",
   site_url: "https://public-gold.skia.org",
   tile_freshness: "10m",
   trace_bt_table: "gold-skia",
diff --git a/golden/k8s-instances/skia/skia-skiacorrectness.json5 b/golden/k8s-instances/skia/skia-frontend.json5
similarity index 94%
rename from golden/k8s-instances/skia/skia-skiacorrectness.json5
rename to golden/k8s-instances/skia/skia-frontend.json5
index 5ab6169..366d46c 100644
--- a/golden/k8s-instances/skia/skia-skiacorrectness.json5
+++ b/golden/k8s-instances/skia/skia-frontend.json5
@@ -19,7 +19,7 @@
   port: ":8000",
   positives_max_age: "720h", // 30 days
   prom_port: ":20000",
-  resources_path: "/usr/local/share/skiacorrectness/dist",
+  resources_path: "/usr/local/share/frontend/dist",
   site_url: "https://gold.skia.org",
   tile_freshness: "5m",
   trace_bt_table: "gold-skia",
diff --git a/golden/k8s_release_diff_server b/golden/k8s_release_diff_server
index 6ac5948..e3de04c 100755
--- a/golden/k8s_release_diff_server
+++ b/golden/k8s_release_diff_server
@@ -2,7 +2,7 @@
 
 set -x -e
 
-# Create and upload a container image for skiacorrectness the main Gold process.
+# Create and upload a container image for the (deprecated) Gold diff server.
 APPNAME=gold-diff-server
 
 # Copy files into the right locations in ${ROOT}.
diff --git a/golden/k8s_release_frontend b/golden/k8s_release_frontend
new file mode 100755
index 0000000..d862f32
--- /dev/null
+++ b/golden/k8s_release_frontend
@@ -0,0 +1,23 @@
+#!/bin/bash
+
+set -x -e
+
+# Create and upload a container image the Gold frontend.
+APPNAME=gold-frontend
+
+# Copy files into the right locations in ${ROOT}.
+copy_release_files()
+{
+INSTALL="install -D --verbose --backup=none"
+INSTALL_DIR="install -d --verbose --backup=none"
+
+# Add the dockerfile and binary.
+${INSTALL} --mode=644 -T ./dockerfiles/Dockerfile_frontend  ${ROOT}/Dockerfile
+${INSTALL} --mode=755 -T ./build/frontend_k8s               ${ROOT}/usr/local/bin/${APPNAME}
+
+# Add the frontend assets.
+${INSTALL_DIR} --mode=755                                   ${ROOT}/usr/local/share/frontend/dist
+${INSTALL} --mode=644 ./dist/*                              ${ROOT}/usr/local/share/frontend/dist
+}
+
+source ../bash/docker_build.sh
diff --git a/golden/k8s_release_skiacorrectness b/golden/k8s_release_skiacorrectness
deleted file mode 100755
index 342bf85..0000000
--- a/golden/k8s_release_skiacorrectness
+++ /dev/null
@@ -1,23 +0,0 @@
-#!/bin/bash
-
-set -x -e
-
-# Create and upload a container image for skiacorrectness the main Gold process.
-APPNAME=gold-skiacorrectness
-
-# Copy files into the right locations in ${ROOT}.
-copy_release_files()
-{
-INSTALL="install -D --verbose --backup=none"
-INSTALL_DIR="install -d --verbose --backup=none"
-
-# Add the dockerfile and binary.
-${INSTALL} --mode=644 -T ./dockerfiles/Dockerfile_skiacorrectness  ${ROOT}/Dockerfile
-${INSTALL} --mode=755 -T ./build/skiacorrectness_k8s               ${ROOT}/usr/local/bin/${APPNAME}
-
-# Add the frontend assets.
-${INSTALL_DIR} --mode=755                                          ${ROOT}/usr/local/share/skiacorrectness/dist
-${INSTALL} --mode=644 ./dist/*                                     ${ROOT}/usr/local/share/skiacorrectness/dist
-}
-
-source ../bash/docker_build.sh
diff --git a/skfe/computed.json b/skfe/computed.json
index 53fe8fd..d406a4b 100644
--- a/skfe/computed.json
+++ b/skfe/computed.json
@@ -67,7 +67,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-skia-skiacorrectness",
+          "cluster_name": "gold-skia-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -75,7 +75,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-skia-skiacorrectness",
+                        "address": "gold-skia-frontend",
                         "port_value": 8000
                       }
                     }
@@ -85,7 +85,7 @@
             }
           ]
         },
-        "name": "gold-skia-skiacorrectness",
+        "name": "gold-skia-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -145,7 +145,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-skia-infra-skiacorrectness",
+          "cluster_name": "gold-skia-infra-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -153,7 +153,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-skia-infra-skiacorrectness",
+                        "address": "gold-skia-infra-frontend",
                         "port_value": 8000
                       }
                     }
@@ -163,7 +163,7 @@
             }
           ]
         },
-        "name": "gold-skia-infra-skiacorrectness",
+        "name": "gold-skia-infra-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -171,7 +171,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-skia-public-skiacorrectness",
+          "cluster_name": "gold-skia-public-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -179,7 +179,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-skia-public-skiacorrectness",
+                        "address": "gold-skia-public-frontend",
                         "port_value": 8000
                       }
                     }
@@ -189,7 +189,7 @@
             }
           ]
         },
-        "name": "gold-skia-public-skiacorrectness",
+        "name": "gold-skia-public-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -223,7 +223,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-lottie-skiacorrectness",
+          "cluster_name": "gold-lottie-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -231,7 +231,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-lottie-skiacorrectness",
+                        "address": "gold-lottie-frontend",
                         "port_value": 8000
                       }
                     }
@@ -241,7 +241,7 @@
             }
           ]
         },
-        "name": "gold-lottie-skiacorrectness",
+        "name": "gold-lottie-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -275,7 +275,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-pdfium-skiacorrectness",
+          "cluster_name": "gold-pdfium-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -283,7 +283,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-pdfium-skiacorrectness",
+                        "address": "gold-pdfium-frontend",
                         "port_value": 8000
                       }
                     }
@@ -293,7 +293,7 @@
             }
           ]
         },
-        "name": "gold-pdfium-skiacorrectness",
+        "name": "gold-pdfium-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -353,7 +353,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-flutter-skiacorrectness",
+          "cluster_name": "gold-flutter-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -361,7 +361,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-flutter-skiacorrectness",
+                        "address": "gold-flutter-frontend",
                         "port_value": 8000
                       }
                     }
@@ -371,7 +371,7 @@
             }
           ]
         },
-        "name": "gold-flutter-skiacorrectness",
+        "name": "gold-flutter-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -431,7 +431,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-angle-skiacorrectness",
+          "cluster_name": "gold-angle-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -439,7 +439,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-angle-skiacorrectness",
+                        "address": "gold-angle-frontend",
                         "port_value": 8000
                       }
                     }
@@ -449,7 +449,7 @@
             }
           ]
         },
-        "name": "gold-angle-skiacorrectness",
+        "name": "gold-angle-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -509,7 +509,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-chrome-skiacorrectness",
+          "cluster_name": "gold-chrome-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -517,7 +517,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-chrome-skiacorrectness",
+                        "address": "gold-chrome-frontend",
                         "port_value": 8000
                       }
                     }
@@ -527,7 +527,7 @@
             }
           ]
         },
-        "name": "gold-chrome-skiacorrectness",
+        "name": "gold-chrome-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -535,7 +535,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-chrome-public-skiacorrectness",
+          "cluster_name": "gold-chrome-public-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -543,7 +543,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-chrome-public-skiacorrectness",
+                        "address": "gold-chrome-public-frontend",
                         "port_value": 8000
                       }
                     }
@@ -553,7 +553,7 @@
             }
           ]
         },
-        "name": "gold-chrome-public-skiacorrectness",
+        "name": "gold-chrome-public-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -613,7 +613,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-cros-tast-dev-skiacorrectness",
+          "cluster_name": "gold-cros-tast-dev-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -621,7 +621,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-cros-tast-dev-skiacorrectness",
+                        "address": "gold-cros-tast-dev-frontend",
                         "port_value": 8000
                       }
                     }
@@ -631,7 +631,7 @@
             }
           ]
         },
-        "name": "gold-cros-tast-dev-skiacorrectness",
+        "name": "gold-cros-tast-dev-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -691,7 +691,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-flutter-engine-skiacorrectness",
+          "cluster_name": "gold-flutter-engine-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -699,7 +699,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-flutter-engine-skiacorrectness",
+                        "address": "gold-flutter-engine-frontend",
                         "port_value": 8000
                       }
                     }
@@ -709,7 +709,7 @@
             }
           ]
         },
-        "name": "gold-flutter-engine-skiacorrectness",
+        "name": "gold-flutter-engine-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -769,7 +769,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-fuchsia-public-skiacorrectness",
+          "cluster_name": "gold-fuchsia-public-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -777,7 +777,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-fuchsia-public-skiacorrectness",
+                        "address": "gold-fuchsia-public-frontend",
                         "port_value": 8000
                       }
                     }
@@ -787,7 +787,7 @@
             }
           ]
         },
-        "name": "gold-fuchsia-public-skiacorrectness",
+        "name": "gold-fuchsia-public-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -2763,7 +2763,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-skia-skiacorrectness",
+                            "cluster": "gold-skia-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -2791,7 +2791,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-skia-public-skiacorrectness",
+                            "cluster": "gold-skia-public-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -2819,7 +2819,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-lottie-skiacorrectness",
+                            "cluster": "gold-lottie-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -2847,7 +2847,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-pdfium-skiacorrectness",
+                            "cluster": "gold-pdfium-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -2925,7 +2925,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-flutter-skiacorrectness",
+                            "cluster": "gold-flutter-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -3003,7 +3003,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-angle-skiacorrectness",
+                            "cluster": "gold-angle-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -3081,7 +3081,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-chrome-skiacorrectness",
+                            "cluster": "gold-chrome-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -3109,7 +3109,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-chrome-public-skiacorrectness",
+                            "cluster": "gold-chrome-public-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -3187,7 +3187,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-cros-tast-dev-skiacorrectness",
+                            "cluster": "gold-cros-tast-dev-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -3265,7 +3265,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-flutter-engine-skiacorrectness",
+                            "cluster": "gold-flutter-engine-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -3343,7 +3343,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-fuchsia-public-skiacorrectness",
+                            "cluster": "gold-fuchsia-public-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -3421,7 +3421,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-skia-infra-skiacorrectness",
+                            "cluster": "gold-skia-infra-frontend",
                             "timeout": {
                               "seconds": 600
                             }
diff --git a/skfe/envoy-starter.json b/skfe/envoy-starter.json
index 706ee53..cd28505 100644
--- a/skfe/envoy-starter.json
+++ b/skfe/envoy-starter.json
@@ -67,7 +67,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-skia-skiacorrectness",
+          "cluster_name": "gold-skia-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -75,7 +75,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-skia-skiacorrectness",
+                        "address": "gold-skia-frontend",
                         "port_value": 8000
                       }
                     }
@@ -85,7 +85,7 @@
             }
           ]
         },
-        "name": "gold-skia-skiacorrectness",
+        "name": "gold-skia-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -145,7 +145,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-skia-infra-skiacorrectness",
+          "cluster_name": "gold-skia-infra-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -153,7 +153,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-skia-infra-skiacorrectness",
+                        "address": "gold-skia-infra-frontend",
                         "port_value": 8000
                       }
                     }
@@ -163,7 +163,7 @@
             }
           ]
         },
-        "name": "gold-skia-infra-skiacorrectness",
+        "name": "gold-skia-infra-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -171,7 +171,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-skia-public-skiacorrectness",
+          "cluster_name": "gold-skia-public-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -179,7 +179,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-skia-public-skiacorrectness",
+                        "address": "gold-skia-public-frontend",
                         "port_value": 8000
                       }
                     }
@@ -189,7 +189,7 @@
             }
           ]
         },
-        "name": "gold-skia-public-skiacorrectness",
+        "name": "gold-skia-public-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -223,7 +223,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-lottie-skiacorrectness",
+          "cluster_name": "gold-lottie-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -231,7 +231,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-lottie-skiacorrectness",
+                        "address": "gold-lottie-frontend",
                         "port_value": 8000
                       }
                     }
@@ -241,7 +241,7 @@
             }
           ]
         },
-        "name": "gold-lottie-skiacorrectness",
+        "name": "gold-lottie-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -275,7 +275,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-pdfium-skiacorrectness",
+          "cluster_name": "gold-pdfium-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -283,7 +283,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-pdfium-skiacorrectness",
+                        "address": "gold-pdfium-frontend",
                         "port_value": 8000
                       }
                     }
@@ -293,7 +293,7 @@
             }
           ]
         },
-        "name": "gold-pdfium-skiacorrectness",
+        "name": "gold-pdfium-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -353,7 +353,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-flutter-skiacorrectness",
+          "cluster_name": "gold-flutter-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -361,7 +361,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-flutter-skiacorrectness",
+                        "address": "gold-flutter-frontend",
                         "port_value": 8000
                       }
                     }
@@ -371,7 +371,7 @@
             }
           ]
         },
-        "name": "gold-flutter-skiacorrectness",
+        "name": "gold-flutter-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -431,7 +431,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-angle-skiacorrectness",
+          "cluster_name": "gold-angle-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -439,7 +439,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-angle-skiacorrectness",
+                        "address": "gold-angle-frontend",
                         "port_value": 8000
                       }
                     }
@@ -449,7 +449,7 @@
             }
           ]
         },
-        "name": "gold-angle-skiacorrectness",
+        "name": "gold-angle-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -509,7 +509,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-chrome-skiacorrectness",
+          "cluster_name": "gold-chrome-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -517,7 +517,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-chrome-skiacorrectness",
+                        "address": "gold-chrome-frontend",
                         "port_value": 8000
                       }
                     }
@@ -527,7 +527,7 @@
             }
           ]
         },
-        "name": "gold-chrome-skiacorrectness",
+        "name": "gold-chrome-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -535,7 +535,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-chrome-public-skiacorrectness",
+          "cluster_name": "gold-chrome-public-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -543,7 +543,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-chrome-public-skiacorrectness",
+                        "address": "gold-chrome-public-frontend",
                         "port_value": 8000
                       }
                     }
@@ -553,7 +553,7 @@
             }
           ]
         },
-        "name": "gold-chrome-public-skiacorrectness",
+        "name": "gold-chrome-public-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -613,7 +613,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-cros-tast-dev-skiacorrectness",
+          "cluster_name": "gold-cros-tast-dev-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -621,7 +621,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-cros-tast-dev-skiacorrectness",
+                        "address": "gold-cros-tast-dev-frontend",
                         "port_value": 8000
                       }
                     }
@@ -631,7 +631,7 @@
             }
           ]
         },
-        "name": "gold-cros-tast-dev-skiacorrectness",
+        "name": "gold-cros-tast-dev-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -691,7 +691,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-flutter-engine-skiacorrectness",
+          "cluster_name": "gold-flutter-engine-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -699,7 +699,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-flutter-engine-skiacorrectness",
+                        "address": "gold-flutter-engine-frontend",
                         "port_value": 8000
                       }
                     }
@@ -709,7 +709,7 @@
             }
           ]
         },
-        "name": "gold-flutter-engine-skiacorrectness",
+        "name": "gold-flutter-engine-frontend",
         "type": "STRICT_DNS"
       },
       {
@@ -769,7 +769,7 @@
           "seconds": 1
         },
         "load_assignment": {
-          "cluster_name": "gold-fuchsia-public-skiacorrectness",
+          "cluster_name": "gold-fuchsia-public-frontend",
           "endpoints": [
             {
               "lb_endpoints": [
@@ -777,7 +777,7 @@
                   "endpoint": {
                     "address": {
                       "socket_address": {
-                        "address": "gold-fuchsia-public-skiacorrectness",
+                        "address": "gold-fuchsia-public-frontend",
                         "port_value": 8000
                       }
                     }
@@ -787,7 +787,7 @@
             }
           ]
         },
-        "name": "gold-fuchsia-public-skiacorrectness",
+        "name": "gold-fuchsia-public-frontend",
         "type": "STRICT_DNS"
       }
     ],
@@ -1594,7 +1594,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-skia-skiacorrectness",
+                            "cluster": "gold-skia-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -1622,7 +1622,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-skia-public-skiacorrectness",
+                            "cluster": "gold-skia-public-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -1650,7 +1650,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-lottie-skiacorrectness",
+                            "cluster": "gold-lottie-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -1678,7 +1678,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-pdfium-skiacorrectness",
+                            "cluster": "gold-pdfium-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -1756,7 +1756,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-flutter-skiacorrectness",
+                            "cluster": "gold-flutter-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -1834,7 +1834,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-angle-skiacorrectness",
+                            "cluster": "gold-angle-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -1912,7 +1912,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-chrome-skiacorrectness",
+                            "cluster": "gold-chrome-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -1940,7 +1940,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-chrome-public-skiacorrectness",
+                            "cluster": "gold-chrome-public-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -2018,7 +2018,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-cros-tast-dev-skiacorrectness",
+                            "cluster": "gold-cros-tast-dev-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -2096,7 +2096,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-flutter-engine-skiacorrectness",
+                            "cluster": "gold-flutter-engine-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -2174,7 +2174,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-fuchsia-public-skiacorrectness",
+                            "cluster": "gold-fuchsia-public-frontend",
                             "timeout": {
                               "seconds": 600
                             }
@@ -2252,7 +2252,7 @@
                             "prefix": "/"
                           },
                           "route": {
-                            "cluster": "gold-skia-infra-skiacorrectness",
+                            "cluster": "gold-skia-infra-frontend",
                             "timeout": {
                               "seconds": 600
                             }
diff --git a/skolo/ios/package.sh b/skolo/ios/package.sh
index c7da9dc..78a52cf 100755
--- a/skolo/ios/package.sh
+++ b/skolo/ios/package.sh
@@ -5,7 +5,7 @@
 APPNAME=imobiledevice
 SERVICE_FILE="path-to-service-file.service"
 
-# Builds and uploads a debian package for skiacorrectness.
+# Builds and uploads a debian package for libimobiledevice.
 SYSTEMD="usbmuxd.service"
 DESCRIPTION="Latest versions of libimobiledevice and related tools."
 IN_DIR="$(pwd)/out"
diff --git a/golden/cmd/goldpushk/goldpushk/services_map.go b/golden/cmd/goldpushk/goldpushk/services_map.go
index ebd336a..1cbdea3 100644
--- a/golden/cmd/goldpushk/goldpushk/services_map.go
+++ b/golden/cmd/goldpushk/goldpushk/services_map.go
@@ -20,11 +20,11 @@
 	SkiaPublic        Instance = "skia-public"
 
 	// Gold services.
-	BaselineServer  Service = "baselineserver"
-	DiffCalculator  Service = "diffcalculator"
-	DiffServer      Service = "diffserver"
-	IngestionBT     Service = "ingestion-bt"
-	SkiaCorrectness Service = "skiacorrectness"
+	BaselineServer Service = "baselineserver"
+	DiffCalculator Service = "diffcalculator"
+	DiffServer     Service = "diffserver"
+	IngestionBT    Service = "ingestion-bt"
+	Frontend       Service = "frontend"
 
 	// Testing Gold instances.
 	TestInstance1     Instance = "goldpushk-test1"
@@ -71,7 +71,7 @@
 			BaselineServer,
 			DiffServer,
 			IngestionBT,
-			SkiaCorrectness,
+			Frontend,
 			DiffCalculator,
 		},
 	}
@@ -79,13 +79,13 @@
 	// Add common services to all known instances.
 	for _, instance := range s.knownInstances {
 		if isPublicInstance(instance) {
-			// There is only one service for public view instances: - skiacorrectness.
-			s.add(instance, SkiaCorrectness)
+			// There is only one service for public view instances: - frontend.
+			s.add(instance, Frontend)
 		} else {
 			// Add common services for regular instances.
 			s.add(instance, DiffServer)
 			s.add(instance, IngestionBT)
-			s.add(instance, SkiaCorrectness)
+			s.add(instance, Frontend)
 			s.add(instance, DiffCalculator)
 		}
 	}
@@ -107,7 +107,7 @@
 		internal: true,
 	})
 	s.addWithOptions(Fuchsia, IngestionBT, DeploymentOptions{internal: true})
-	s.addWithOptions(Fuchsia, SkiaCorrectness, DeploymentOptions{internal: true})
+	s.addWithOptions(Fuchsia, Frontend, DeploymentOptions{internal: true})
 	s.addWithOptions(Fuchsia, DiffCalculator, DeploymentOptions{internal: true})
 	return s
 }